# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class AttributeTypeUpdate(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attribute_type_update': 'AttributeTypeUpdateAttributeTypeUpdate',
        'current_name': 'str',
        'entity_type': 'str'
    }

    attribute_map = {
        'attribute_type_update': 'attribute_type_update',
        'current_name': 'current_name',
        'entity_type': 'entity_type'
    }

    def __init__(self, attribute_type_update=None, current_name=None, entity_type=None, local_vars_configuration=None):  # noqa: E501
        """AttributeTypeUpdate - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attribute_type_update = None
        self._current_name = None
        self._entity_type = None
        self.discriminator = None

        self.attribute_type_update = attribute_type_update
        self.current_name = current_name
        self.entity_type = entity_type

    @property
    def attribute_type_update(self):
        """

        :return: The attribute_type_update of this AttributeTypeUpdate. 
        :rtype: AttributeTypeUpdateAttributeTypeUpdate
        """
        return self._attribute_type_update

    @attribute_type_update.setter
    def attribute_type_update(self, attribute_type_update):
        """

        :param attribute_type_update: The attribute_type_update of this AttributeTypeUpdate.
        :type: AttributeTypeUpdateAttributeTypeUpdate
        """
        if self.local_vars_configuration.client_side_validation and attribute_type_update is None:  # noqa: E501
            raise ValueError("Invalid value for `attribute_type_update`, must not be `None`")  # noqa: E501

        self._attribute_type_update = attribute_type_update

    @property
    def current_name(self):
        """
        The attribute to rename.

        :return: The current_name of this AttributeTypeUpdate. 
        :rtype: str
        """
        return self._current_name

    @current_name.setter
    def current_name(self, current_name):
        """
        The attribute to rename.

        :param current_name: The current_name of this AttributeTypeUpdate.
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and current_name is None:  # noqa: E501
            raise ValueError("Invalid value for `current_name`, must not be `None`")  # noqa: E501

        self._current_name = current_name

    @property
    def entity_type(self):
        """
        The entity type containing the attribute to rename.

        :return: The entity_type of this AttributeTypeUpdate. 
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        The entity type containing the attribute to rename.

        :param entity_type: The entity_type of this AttributeTypeUpdate.
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["FileType", "MediaType", "LocalizationType", "StateType", "LeafType", "Section"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttributeTypeUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttributeTypeUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class OrganizationUpdate(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'default_membership_permission': 'str',
        'name': 'str',
        'thumb': 'str'
    }

    attribute_map = {
        'default_membership_permission': 'default_membership_permission',
        'name': 'name',
        'thumb': 'thumb'
    }

    def __init__(self, default_membership_permission=None, name=None, thumb=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationUpdate - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._default_membership_permission = None
        self._name = None
        self._thumb = None
        self.discriminator = None

        if default_membership_permission is not None:
            self.default_membership_permission = default_membership_permission
        if name is not None:
            self.name = name
        if thumb is not None:
            self.thumb = thumb

    @property
    def default_membership_permission(self):
        """
        Default user permission level for all projects in this organization. If specified, users in this organizaiton will be automatically added to all projects in this organization with at least this permission level.

        :return: The default_membership_permission of this OrganizationUpdate. 
        :rtype: str
        """
        return self._default_membership_permission

    @default_membership_permission.setter
    def default_membership_permission(self, default_membership_permission):
        """
        Default user permission level for all projects in this organization. If specified, users in this organizaiton will be automatically added to all projects in this organization with at least this permission level.

        :param default_membership_permission: The default_membership_permission of this OrganizationUpdate.
        :type: str
        """
        allowed_values = ["No Access", "View Only", "Can Edit", "Can Transfer", "Can Execute", "Full Control"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and default_membership_permission not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `default_membership_permission` ({0}), must be one of {1}"  # noqa: E501
                .format(default_membership_permission, allowed_values)
            )

        self._default_membership_permission = default_membership_permission

    @property
    def name(self):
        """
        Name of the organization.

        :return: The name of this OrganizationUpdate. 
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Name of the organization.

        :param name: The name of this OrganizationUpdate.
        :type: str
        """

        self._name = name

    @property
    def thumb(self):
        """
        S3 key of thumbnail used to represent the organization.

        :return: The thumb of this OrganizationUpdate. 
        :rtype: str
        """
        return self._thumb

    @thumb.setter
    def thumb(self, thumb):
        """
        S3 key of thumbnail used to represent the organization.

        :param thumb: The thumb of this OrganizationUpdate.
        :type: str
        """

        self._thumb = thumb

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationUpdate):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/env python

import argparse
import os
import shutil
import sys
from uuid import uuid1
import logging
import json

from progressbar import progressbar
import requests
from tator.openapi.tator_openapi.models import MessageResponse

from ..util import md5sum
from ..util.get_api import get_api

from .create_media import create_media
from .determine_transcode import determine_transcode
from .transcode import convert_streaming
from .transcode import convert_archival
from .transcode import convert_audio
from .delete_media import delete_media
from .make_thumbnails import make_thumbnails

if os.getenv("DD_LOGS_INJECTION"):
    import ddtrace.auto
    FORMAT = ('%(asctime)s %(levelname)s [%(name)s] [%(filename)s:%(lineno)d] '
              '[dd.service=%(dd.service)s dd.env=%(dd.env)s dd.version=%(dd.version)s dd.trace_id=%(dd.trace_id)s dd.span_id=%(dd.span_id)s] '
              '- %(message)s')
else:
    FORMAT = ('%(asctime)s %(levelname)s [%(name)s] [%(filename)s:%(lineno)d] '
              '- %(message)s')
logging.basicConfig(format=FORMAT)
logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

def parse_args():
    parser = argparse.ArgumentParser(description='Full transcode pipeline on a directory of files.')
    parser.add_argument('path', nargs='?', type=str,
                        help='Path to directory containing video files, or a video file. '
                             'Ignored if --url is given.')
    parser.add_argument('--extension', type=str, default='mp4', help='File extension to upload. '
                                                                     'Ignored if path is a file.')
    parser.add_argument('--work_dir', type=str, help='Path to working directory. If not given, '
                                                     'the path containing videos will be used.')
    parser.add_argument('--url', type=str, help='URL where original file is hosted.')
    parser.add_argument('--host', type=str, default='https://cloud.tator.io', help='Host URL.')
    parser.add_argument('--token', type=str, help='REST API token.')
    parser.add_argument('--project', type=int, help='Unique integer specifying project ID.')
    parser.add_argument('--type', type=int, help='Unique integer specifying a media type.')
    parser.add_argument('--name', type=str, help='Name of the media.')
    parser.add_argument('--section', type=str, help='Media section name.')
    parser.add_argument('--section_id', type=int, help='Media section ID. If given `--section` is ignored.')
    parser.add_argument('--attributes', type=str, help="Attributes for media as a JSON string.")
    parser.add_argument('--media_id', type=int, help="Existing media ID, if applicable",
                        default=-1)
    parser.add_argument('--gid', type=str, help="Upload group ID.")
    parser.add_argument('--uid', type=str, help="Upload unique ID.")
    parser.add_argument('--group_to', type=int, default=1080,
                         help='Vertical resolutions below this will be transcoded with '
                              'multi-headed ffmpeg.')
    parser.add_argument('--email_spec', type=str, help="Optional email spec as a JSON string. The email will be sent upon completion of the transcode (see Email rest endpoint docs).")
    parser.add_argument('--cleanup', action='store_true',
                        help="Deletes working files after each file is transcoded and "
                             "uploaded.")
    parser.add_argument('--hwaccel', action='store_true', help="Use hardware acceleration.")
    return parser.parse_args()

def get_file_paths(path, base):
    paths = {
        'original': path,
        'transcoded': base + '_transcoded',
        'thumbnail': base + '_thumbnail.jpg',
        'thumbnail_gif': base + '_thumbnail_gif.gif',
    }
    return paths

def transcode_single(path, args, gid):
    """Transcodes a single file.
    """
    logging.basicConfig(stream=sys.stdout, level=logging.INFO)

    # If a URL is given and path doesn't exist, download the file to path.
    if args.url:
        path = os.path.join(args.work_dir, args.name)
        response = requests.get(args.url, stream=True)
        response.raise_for_status()
        with open(path, "wb") as fp:
            for chunk in response.iter_content(chunk_size=10485760):  # 10 MiB
                if chunk:
                    fp.write(chunk)
    elif path is None:
        raise ValueError(f"Must provide one of --url or path!")

    # Get file paths.
    if args.work_dir:
        base = os.path.join(args.work_dir, os.path.splitext(os.path.basename(path))[0])
    else:
        base, _ = os.path.splitext(path)
    paths = get_file_paths(path, base)

    # Get md5 for the file.
    md5 = md5sum(paths['original'])

    # Get base filename.
    if args.name:
        name = args.name
    else:
        name = os.path.basename(paths['original'])

    # Create a uid if not set.
    if args.uid is None:
        uid = str(uuid1())
    else:
        uid = args.uid

    # Create the media object.
    if args.media_id == -1:
        kwargs = {}
        if args.section_id:
            kwargs['section_id'] = args.section_id
            args.section = None
        media_id = create_media(args.host, args.token, args.project, args.type, args.section,
                                name, md5, gid, uid, args.attributes, args.url, **kwargs)
    else:
        media_id = args.media_id

    try:
        # Make thumbnails.
        make_thumbnails(args.host, args.token, media_id, paths['original'], paths['thumbnail'],
                        paths['thumbnail_gif'])

        # Determine transcodes that need to be done.
        workloads = determine_transcode(
            args.host, args.token, args.type, media_id, path, group_to=args.group_to
        )

        # Transcode the video file.
        for workload in workloads:
            category = workload['category']
            del workload['category']
            del workload['id']
            if category == 'streaming':
                convert_streaming(**workload, host=args.host, token=args.token, media=media_id,
                                  outpath=paths['transcoded'], hwaccel=args.hwaccel)
            elif category == 'archival':
                del workload['configs']
                convert_archival(**workload, host=args.host, token=args.token, media=media_id,
                                 outpath=paths['transcoded'], hwaccel=args.hwaccel)
            elif category == 'audio':
                del workload['configs']
                del workload['raw_width']
                del workload['raw_height']
                convert_audio(**workload, host=args.host, token=args.token, media=media_id,
                              outpath=paths['transcoded'])
    except Exception as exc:
        logging.error("Encountered exception!", exc_info=True)
        if args.media_id == -1:
            delete_media(args.host, args.token, media_id)
        raise RuntimeError(f"Transcode of file {path} failed!") from exc

    # Clean up after the transcode is finished (if enabled).
    if args.cleanup:
        for key in ['transcoded', 'thumbnail', 'thumbnail_gif']:
            path = paths[key]
            if os.path.isdir(path):
                shutil.rmtree(path)
            else:
                os.remove(path)

    # Send an email.
    if isinstance(args.email_spec, str):
        try:
            email_spec = json.loads(args.email_spec)
        except json.JSONDecodeError:
            logger.warning(
                "Could not decode email_spec string '%s'", args.email_spec, exc_info=True
            )
            email_spec = None
    else:
        email_spec = args.email_spec

    if email_spec:
        api = get_api(args.host, args.token)
        response = api.send_email(args.project, email_spec=email_spec)
        if isinstance(response, MessageResponse):
            logger.info(response.message)

def transcode_main(args):
    if args.gid is None:
        gid = str(uuid1())
    else:
        gid = args.gid
    if args.path and os.path.isdir(args.path):
        file_list = []
        for root, _, files in os.walk(args.path):
            for fname in files:
                if fname.endswith(args.extension):
                    path = os.path.join(root, fname)
                    file_list.append(path)
        for path in progressbar(file_list):
            transcode_single(path, args, gid)
    else:
        transcode_single(args.path, args, gid)
    
if __name__ == '__main__':
    args = parse_args()
    transcode_main(args)



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class S3StorageConfig(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_access_key': 'str',
        'aws_secret_access_key': 'str',
        'bucket_name': 'str'
    }

    attribute_map = {
        'aws_access_key': 'aws_access_key',
        'aws_secret_access_key': 'aws_secret_access_key',
        'bucket_name': 'bucket_name'
    }

    def __init__(self, aws_access_key=None, aws_secret_access_key=None, bucket_name=None, local_vars_configuration=None):  # noqa: E501
        """S3StorageConfig - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._aws_access_key = None
        self._aws_secret_access_key = None
        self._bucket_name = None
        self.discriminator = None

        if aws_access_key is not None:
            self.aws_access_key = aws_access_key
        if aws_secret_access_key is not None:
            self.aws_secret_access_key = aws_secret_access_key
        if bucket_name is not None:
            self.bucket_name = bucket_name

    @property
    def aws_access_key(self):
        """
        AWS access key.

        :return: The aws_access_key of this S3StorageConfig. 
        :rtype: str
        """
        return self._aws_access_key

    @aws_access_key.setter
    def aws_access_key(self, aws_access_key):
        """
        AWS access key.

        :param aws_access_key: The aws_access_key of this S3StorageConfig.
        :type: str
        """

        self._aws_access_key = aws_access_key

    @property
    def aws_secret_access_key(self):
        """
        AWS secret access key.

        :return: The aws_secret_access_key of this S3StorageConfig. 
        :rtype: str
        """
        return self._aws_secret_access_key

    @aws_secret_access_key.setter
    def aws_secret_access_key(self, aws_secret_access_key):
        """
        AWS secret access key.

        :param aws_secret_access_key: The aws_secret_access_key of this S3StorageConfig.
        :type: str
        """

        self._aws_secret_access_key = aws_secret_access_key

    @property
    def bucket_name(self):
        """
        Name of bucket.

        :return: The bucket_name of this S3StorageConfig. 
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Name of bucket.

        :param bucket_name: The bucket_name of this S3StorageConfig.
        :type: str
        """

        self._bucket_name = bucket_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3StorageConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3StorageConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class File(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attributes': 'dict(str, object)',
        'created_by': 'int',
        'created_datetime': 'datetime',
        'description': 'str',
        'elemental_id': 'str',
        'id': 'int',
        'modified_by': 'int',
        'modified_datetime': 'datetime',
        'name': 'str',
        'path': 'str',
        'project': 'int',
        'type': 'int'
    }

    attribute_map = {
        'attributes': 'attributes',
        'created_by': 'created_by',
        'created_datetime': 'created_datetime',
        'description': 'description',
        'elemental_id': 'elemental_id',
        'id': 'id',
        'modified_by': 'modified_by',
        'modified_datetime': 'modified_datetime',
        'name': 'name',
        'path': 'path',
        'project': 'project',
        'type': 'type'
    }

    def __init__(self, attributes=None, created_by=None, created_datetime=None, description=None, elemental_id=None, id=None, modified_by=None, modified_datetime=None, name=None, path=None, project=None, type=None, local_vars_configuration=None):  # noqa: E501
        """File - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attributes = None
        self._created_by = None
        self._created_datetime = None
        self._description = None
        self._elemental_id = None
        self._id = None
        self._modified_by = None
        self._modified_datetime = None
        self._name = None
        self._path = None
        self._project = None
        self._type = None
        self.discriminator = None

        if attributes is not None:
            self.attributes = attributes
        if created_by is not None:
            self.created_by = created_by
        if created_datetime is not None:
            self.created_datetime = created_datetime
        if description is not None:
            self.description = description
        self.elemental_id = elemental_id
        if id is not None:
            self.id = id
        if modified_by is not None:
            self.modified_by = modified_by
        if modified_datetime is not None:
            self.modified_datetime = modified_datetime
        if name is not None:
            self.name = name
        if path is not None:
            self.path = path
        if project is not None:
            self.project = project
        if type is not None:
            self.type = type

    @property
    def attributes(self):
        """
        Object containing attribute values

        :return: The attributes of this File. 
        :rtype: dict(str, object)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Object containing attribute values

        :param attributes: The attributes of this File.
        :type: dict(str, object)
        """

        self._attributes = attributes

    @property
    def created_by(self):
        """
        User that created this file

        :return: The created_by of this File. 
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        User that created this file

        :param created_by: The created_by of this File.
        :type: int
        """

        self._created_by = created_by

    @property
    def created_datetime(self):
        """
        Datetime this file was created

        :return: The created_datetime of this File. 
        :rtype: datetime
        """
        return self._created_datetime

    @created_datetime.setter
    def created_datetime(self, created_datetime):
        """
        Datetime this file was created

        :param created_datetime: The created_datetime of this File.
        :type: datetime
        """

        self._created_datetime = created_datetime

    @property
    def description(self):
        """
        Description of file

        :return: The description of this File. 
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Description of file

        :param description: The description of this File.
        :type: str
        """

        self._description = description

    @property
    def elemental_id(self):
        """
        The elemental ID of the object.

        :return: The elemental_id of this File. 
        :rtype: str
        """
        return self._elemental_id

    @elemental_id.setter
    def elemental_id(self, elemental_id):
        """
        The elemental ID of the object.

        :param elemental_id: The elemental_id of this File.
        :type: str
        """

        self._elemental_id = elemental_id

    @property
    def id(self):
        """
        Unique integer identifying the non-media file

        :return: The id of this File. 
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Unique integer identifying the non-media file

        :param id: The id of this File.
        :type: int
        """

        self._id = id

    @property
    def modified_by(self):
        """
        User who last edited this file

        :return: The modified_by of this File. 
        :rtype: int
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        User who last edited this file

        :param modified_by: The modified_by of this File.
        :type: int
        """

        self._modified_by = modified_by

    @property
    def modified_datetime(self):
        """
        Datetime this file was created

        :return: The modified_datetime of this File. 
        :rtype: datetime
        """
        return self._modified_datetime

    @modified_datetime.setter
    def modified_datetime(self, modified_datetime):
        """
        Datetime this file was created

        :param modified_datetime: The modified_datetime of this File.
        :type: datetime
        """

        self._modified_datetime = modified_datetime

    @property
    def name(self):
        """
        Name of file

        :return: The name of this File. 
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Name of file

        :param name: The name of this File.
        :type: str
        """

        self._name = name

    @property
    def path(self):
        """
        Relative URL to the file

        :return: The path of this File. 
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Relative URL to the file

        :param path: The path of this File.
        :type: str
        """

        self._path = path

    @property
    def project(self):
        """
        Unique integer identifying the project associated with the file

        :return: The project of this File. 
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """
        Unique integer identifying the project associated with the file

        :param project: The project of this File.
        :type: int
        """

        self._project = project

    @property
    def type(self):
        """
        Unique integer identifying FileType of this File object.

        :return: The type of this File. 
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Unique integer identifying FileType of this File object.

        :param type: The type of this File.
        :type: int
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, File):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, File):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class VideoDefinition(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bit_rate': 'int',
        'codec': 'str',
        'codec_description': 'str',
        'codec_mime': 'str',
        'host': 'str',
        'http_auth': 'str',
        'path': 'str',
        'reference_only': 'int',
        'resolution': 'list[int]',
        'segment_info': 'str',
        'size': 'int'
    }

    attribute_map = {
        'bit_rate': 'bit_rate',
        'codec': 'codec',
        'codec_description': 'codec_description',
        'codec_mime': 'codec_mime',
        'host': 'host',
        'http_auth': 'http_auth',
        'path': 'path',
        'reference_only': 'reference_only',
        'resolution': 'resolution',
        'segment_info': 'segment_info',
        'size': 'size'
    }

    def __init__(self, bit_rate=None, codec=None, codec_description=None, codec_mime=None, host=None, http_auth=None, path=None, reference_only=0, resolution=None, segment_info=None, size=None, local_vars_configuration=None):  # noqa: E501
        """VideoDefinition - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bit_rate = None
        self._codec = None
        self._codec_description = None
        self._codec_mime = None
        self._host = None
        self._http_auth = None
        self._path = None
        self._reference_only = None
        self._resolution = None
        self._segment_info = None
        self._size = None
        self.discriminator = None

        if bit_rate is not None:
            self.bit_rate = bit_rate
        self.codec = codec
        if codec_description is not None:
            self.codec_description = codec_description
        if codec_mime is not None:
            self.codec_mime = codec_mime
        if host is not None:
            self.host = host
        if http_auth is not None:
            self.http_auth = http_auth
        self.path = path
        if reference_only is not None:
            self.reference_only = reference_only
        self.resolution = resolution
        if segment_info is not None:
            self.segment_info = segment_info
        if size is not None:
            self.size = size

    @property
    def bit_rate(self):
        """
        Bit rate in bits per second

        :return: The bit_rate of this VideoDefinition. 
        :rtype: int
        """
        return self._bit_rate

    @bit_rate.setter
    def bit_rate(self, bit_rate):
        """
        Bit rate in bits per second

        :param bit_rate: The bit_rate of this VideoDefinition.
        :type: int
        """

        self._bit_rate = bit_rate

    @property
    def codec(self):
        """
        Human readable codec.

        :return: The codec of this VideoDefinition. 
        :rtype: str
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        """
        Human readable codec.

        :param codec: The codec of this VideoDefinition.
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and codec is None:  # noqa: E501
            raise ValueError("Invalid value for `codec`, must not be `None`")  # noqa: E501

        self._codec = codec

    @property
    def codec_description(self):
        """
        Description other than codec.

        :return: The codec_description of this VideoDefinition. 
        :rtype: str
        """
        return self._codec_description

    @codec_description.setter
    def codec_description(self, codec_description):
        """
        Description other than codec.

        :param codec_description: The codec_description of this VideoDefinition.
        :type: str
        """

        self._codec_description = codec_description

    @property
    def codec_mime(self):
        """
        Example mime: \"video/mp4; codecs=\"avc1.64001e\"\". Only relevant for streaming files, will assume example above if not present.

        :return: The codec_mime of this VideoDefinition. 
        :rtype: str
        """
        return self._codec_mime

    @codec_mime.setter
    def codec_mime(self, codec_mime):
        """
        Example mime: \"video/mp4; codecs=\"avc1.64001e\"\". Only relevant for streaming files, will assume example above if not present.

        :param codec_mime: The codec_mime of this VideoDefinition.
        :type: str
        """

        self._codec_mime = codec_mime

    @property
    def host(self):
        """
        If supplied will use this instead of currently connected host, e.g. https://example.com

        :return: The host of this VideoDefinition. 
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        If supplied will use this instead of currently connected host, e.g. https://example.com

        :param host: The host of this VideoDefinition.
        :type: str
        """

        self._host = host

    @property
    def http_auth(self):
        """
        If specified will be used for HTTP authorization in request for media, i.e. \"bearer TOKEN\".

        :return: The http_auth of this VideoDefinition. 
        :rtype: str
        """
        return self._http_auth

    @http_auth.setter
    def http_auth(self, http_auth):
        """
        If specified will be used for HTTP authorization in request for media, i.e. \"bearer TOKEN\".

        :param http_auth: The http_auth of this VideoDefinition.
        :type: str
        """

        self._http_auth = http_auth

    @property
    def path(self):
        """
        Relative URL to the file.

        :return: The path of this VideoDefinition. 
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Relative URL to the file.

        :param path: The path of this VideoDefinition.
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def reference_only(self):
        """
        Do not import the media resources into Tator. This causes the resources to be accessed at the supplied URL upon access in the UI.

        :return: The reference_only of this VideoDefinition. 
        :rtype: int
        """
        return self._reference_only

    @reference_only.setter
    def reference_only(self, reference_only):
        """
        Do not import the media resources into Tator. This causes the resources to be accessed at the supplied URL upon access in the UI.

        :param reference_only: The reference_only of this VideoDefinition.
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                reference_only is not None and reference_only > 1):  # noqa: E501
            raise ValueError("Invalid value for `reference_only`, must be a value less than or equal to `1`")  # noqa: E501

        self._reference_only = reference_only

    @property
    def resolution(self):
        """
        Resolution of the video in pixels (height, width).

        :return: The resolution of this VideoDefinition. 
        :rtype: list[int]
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """
        Resolution of the video in pixels (height, width).

        :param resolution: The resolution of this VideoDefinition.
        :type: list[int]
        """
        if self.local_vars_configuration.client_side_validation and resolution is None:  # noqa: E501
            raise ValueError("Invalid value for `resolution`, must not be `None`")  # noqa: E501

        self._resolution = resolution

    @property
    def segment_info(self):
        """
        Path to json file containing segment info. Required if media role is `streaming`.

        :return: The segment_info of this VideoDefinition. 
        :rtype: str
        """
        return self._segment_info

    @segment_info.setter
    def segment_info(self, segment_info):
        """
        Path to json file containing segment info. Required if media role is `streaming`.

        :param segment_info: The segment_info of this VideoDefinition.
        :type: str
        """

        self._segment_info = segment_info

    @property
    def size(self):
        """
        File size in bytes.

        :return: The size of this VideoDefinition. 
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        File size in bytes.

        :param size: The size of this VideoDefinition.
        :type: int
        """

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class MembershipUpdate(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'default_version': 'int',
        'permission': 'str'
    }

    attribute_map = {
        'default_version': 'default_version',
        'permission': 'permission'
    }

    def __init__(self, default_version=None, permission=None, local_vars_configuration=None):  # noqa: E501
        """MembershipUpdate - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._default_version = None
        self._permission = None
        self.discriminator = None

        if default_version is not None:
            self.default_version = default_version
        if permission is not None:
            self.permission = permission

    @property
    def default_version(self):
        """
        Unique integer identifying a version.

        :return: The default_version of this MembershipUpdate. 
        :rtype: int
        """
        return self._default_version

    @default_version.setter
    def default_version(self, default_version):
        """
        Unique integer identifying a version.

        :param default_version: The default_version of this MembershipUpdate.
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                default_version is not None and default_version < 1):  # noqa: E501
            raise ValueError("Invalid value for `default_version`, must be a value greater than or equal to `1`")  # noqa: E501

        self._default_version = default_version

    @property
    def permission(self):
        """
        User permission level for the project.

        :return: The permission of this MembershipUpdate. 
        :rtype: str
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """
        User permission level for the project.

        :param permission: The permission of this MembershipUpdate.
        :type: str
        """
        allowed_values = ["View Only", "Can Edit", "Can Transfer", "Can Execute", "Full Control"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and permission not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `permission` ({0}), must be one of {1}"  # noqa: E501
                .format(permission, allowed_values)
            )

        self._permission = permission

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MembershipUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MembershipUpdate):
            return True

        return self.to_dict() != other.to_dict()
